#[repr(i32)]pub enum aiLightSourceType {
aiLightSource_UNDEFINED = 0,
aiLightSource_DIRECTIONAL = 1,
aiLightSource_POINT = 2,
aiLightSource_SPOT = 3,
aiLightSource_AMBIENT = 4,
aiLightSource_AREA = 5,
_aiLightSource_Force32Bit = 2_147_483_647,
}Expand description
Enumerates all supported types of light sources.
Variants
aiLightSource_UNDEFINED = 0
aiLightSource_DIRECTIONAL = 1
! A directional light source has a well-defined direction ! but is infinitely far away. That’s quite a good ! approximation for sun light.
aiLightSource_POINT = 2
! A point light source has a well-defined position ! in space but no direction - it emits light in all ! directions. A normal bulb is a point light.
aiLightSource_SPOT = 3
! A spot light source emits light in a specific ! angle. It has a position and a direction it is pointing to. ! A good example for a spot light is a light spot in ! sport arenas.
aiLightSource_AMBIENT = 4
! The generic light level of the world, including the bounces ! of all other light sources. ! Typically, there’s at most one ambient light in a scene. ! This light type doesn’t have a valid position, direction, or ! other properties, just a color.
aiLightSource_AREA = 5
! An area light is a rectangle with predefined size that uniformly ! emits light from one of its sides. The position is center of the ! rectangle and direction is its normal vector.
_aiLightSource_Force32Bit = 2_147_483_647