pub unsafe extern "C" fn aiGetMaterialFloatArray(
pMat: *const aiMaterial,
pKey: *const c_char,
type_: c_uint,
index: c_uint,
pOut: *mut ai_real,
pMax: *mut c_uint,
) -> aiReturnExpand description
@brief Retrieve an array of float values with a specific key from the material
Pass one of the AI_MATKEY_XXX constants for the last three parameters (the example reads the #AI_MATKEY_UVTRANSFORM property of the first diffuse texture) @code aiUVTransform trafo; unsigned int max = sizeof(aiUVTransform); if (AI_SUCCESS != aiGetMaterialFloatArray(mat, AI_MATKEY_UVTRANSFORM(aiTextureType_DIFFUSE,0), (float*)&trafo, &max) || sizeof(aiUVTransform) != max) { // error handling } @endcode
@param pMat Pointer to the input material. May not be NULL @param pKey Key to search for. One of the AI_MATKEY_XXX constants. @param pOut Pointer to a buffer to receive the result. @param pMax Specifies the size of the given buffer, in float’s. Receives the number of values (not bytes!) read. @param type (see the code sample above) @param index (see the code sample above) @return Specifies whether the key has been found. If not, the output arrays remains unmodified and pMax is set to 0.