aiMeshKey

Struct aiMeshKey 

#[repr(C)]
pub struct aiMeshKey { pub mTime: f64, pub mValue: c_uint, }
Binds a anim-mesh to a specific point in time.

Fields

mTime: f64

The time of this key

mValue: c_uint

Index into the aiMesh::mAnimMeshes array of the mesh corresponding to the #aiMeshAnim hosting this key frame. The referenced anim mesh is evaluated according to the rules defined in the docs for #aiAnimMesh.