#[repr(i32)]pub enum aiTextureFlags {
aiTextureFlags_Invert = 1,
aiTextureFlags_UseAlpha = 2,
aiTextureFlags_IgnoreAlpha = 4,
_aiTextureFlags_Force32Bit = 2_147_483_647,
}Expand description
@brief Defines some mixed flags for a particular texture.
Usually you’ll instruct your cg artists how textures have to look like … and how they will be processed in your application. However, if you use Assimp for completely generic loading purposes you might also need to process these flags in order to display as many ‘unknown’ 3D models as possible correctly.
This corresponds to the #AI_MATKEY_TEXFLAGS property.
Variants
aiTextureFlags_Invert = 1
The texture’s color values have to be inverted (component-wise 1-n)
aiTextureFlags_UseAlpha = 2
Explicit request to the application to process the alpha channel of the texture.
Mutually exclusive with #aiTextureFlags_IgnoreAlpha. These flags are set if the library can say for sure that the alpha channel is used/is not used. If the model format does not define this, it is left to the application to decide whether the texture alpha channel - if any - is evaluated or not.
aiTextureFlags_IgnoreAlpha = 4
Explicit request to the application to ignore the alpha channel of the texture.
Mutually exclusive with #aiTextureFlags_UseAlpha.
_aiTextureFlags_Force32Bit = 2_147_483_647