#[repr(i32)]pub enum aiTextureMapping {
aiTextureMapping_UV = 0,
aiTextureMapping_SPHERE = 1,
aiTextureMapping_CYLINDER = 2,
aiTextureMapping_BOX = 3,
aiTextureMapping_PLANE = 4,
aiTextureMapping_OTHER = 5,
_aiTextureMapping_Force32Bit = 2_147_483_647,
}Expand description
@brief Defines how the mapping coords for a texture are generated.
Real-time applications typically require full UV coordinates, so the use of the aiProcess_GenUVCoords step is highly recommended. It generates proper UV channels for non-UV mapped objects, as long as an accurate description how the mapping should look like (e.g spherical) is given. See the #AI_MATKEY_MAPPING property for more details.
Variants
aiTextureMapping_UV = 0
The mapping coordinates are taken from an UV channel.
#AI_MATKEY_UVWSRC property specifies from which UV channel the texture coordinates are to be taken from (remember, meshes can have more than one UV channel).
aiTextureMapping_SPHERE = 1
Spherical mapping
aiTextureMapping_CYLINDER = 2
Cylindrical mapping
aiTextureMapping_BOX = 3
Cubic mapping
aiTextureMapping_PLANE = 4
Planar mapping
aiTextureMapping_OTHER = 5
Undefined mapping. Have fun.
_aiTextureMapping_Force32Bit = 2_147_483_647