#[repr(C)]pub struct aiAnimation {
pub mName: aiString,
pub mDuration: f64,
pub mTicksPerSecond: f64,
pub mNumChannels: c_uint,
pub mChannels: *mut *mut aiNodeAnim,
pub mNumMeshChannels: c_uint,
pub mMeshChannels: *mut *mut aiMeshAnim,
pub mNumMorphMeshChannels: c_uint,
pub mMorphMeshChannels: *mut *mut aiMeshMorphAnim,
}Expand description
An animation consists of key-frame data for a number of nodes. For each node affected by the animation a separate series of data is given.
Fields
mName: aiStringThe name of the animation. If the modeling package this data was exported from does support only a single animation channel, this name is usually empty (length is zero).
mDuration: f64Duration of the animation in ticks.
mTicksPerSecond: f64Ticks per second. 0 if not specified in the imported file
mNumChannels: c_uintThe number of bone animation channels. Each channel affects a single node.
mChannels: *mut *mut aiNodeAnimThe node animation channels. Each channel affects a single node. The array is mNumChannels in size.
mNumMeshChannels: c_uintThe number of mesh animation channels. Each channel affects a single mesh and defines vertex-based animation.
mMeshChannels: *mut *mut aiMeshAnimThe mesh animation channels. Each channel affects a single mesh. The array is mNumMeshChannels in size.
mNumMorphMeshChannels: c_uintThe number of mesh animation channels. Each channel affects a single mesh and defines morphing animation.
mMorphMeshChannels: *mut *mut aiMeshMorphAnimThe morph mesh animation channels. Each channel affects a single mesh. The array is mNumMorphMeshChannels in size.