#[repr(C)]pub struct aiFile {
pub ReadProc: aiFileReadProc,
pub WriteProc: aiFileWriteProc,
pub TellProc: aiFileTellProc,
pub FileSizeProc: aiFileTellProc,
pub SeekProc: aiFileSeek,
pub FlushProc: aiFileFlushProc,
pub UserData: aiUserData,
}Expand description
@brief C-API: File callbacks
Actually, it’s a data structure to wrap a set of fXXXX (e.g fopen) replacement functions.
The default implementation of the functions utilizes the fXXX functions from the CRT. However, you can supply a custom implementation to Assimp by delivering a custom aiFileIO. Use this to enable reading from other sources, such as ZIP archives or memory locations.
Fields
ReadProc: aiFileReadProcCallback to read from a file
WriteProc: aiFileWriteProcCallback to write to a file
TellProc: aiFileTellProcCallback to retrieve the current position of the file cursor (ftell())
FileSizeProc: aiFileTellProcCallback to retrieve the size of the file, in bytes
SeekProc: aiFileSeekCallback to set the current position of the file cursor (fseek())
FlushProc: aiFileFlushProcCallback to flush the file contents
UserData: aiUserDataUser-defined, opaque data